diff --git a/build.gradle.kts b/build.gradle.kts
index 39f707195..9b1ff4992 100644
--- a/build.gradle.kts
+++ b/build.gradle.kts
@@ -11,7 +11,7 @@ plugins {
 
 group = "net.minecraft"
 version = "7.2"
-val buildChannel = "PRERELEASE"
+val buildChannel = "STABLE"
 
 run {
     val file = File("version.txt")
@@ -42,8 +42,10 @@ tasks.withType(JavaCompile::class.java) {
     dependsOn(tasks["generateJava"])
     options.isIncremental = false
     options.encoding = "UTF-8"
-    options.compilerArgs.add("--release")
-    options.compilerArgs.add("8")
+    if (JavaVersion.current() != JavaVersion.VERSION_1_8) {
+        options.compilerArgs.add("--release")
+        options.compilerArgs.add("8")
+    }
 }
 
 task("jarClient", ShadowJar::class) {
diff --git a/src/main/java/net/minecraft/client/option/GameSettings.java b/src/main/java/net/minecraft/client/option/GameSettings.java
index 7b29a180b..98459f623 100644
--- a/src/main/java/net/minecraft/client/option/GameSettings.java
+++ b/src/main/java/net/minecraft/client/option/GameSettings.java
@@ -278,7 +278,8 @@ public class GameSettings {
 			return trans.translateKey("options.borderlessFullscreen.unavailable");
 		}
 		if (option instanceof FloatOption) {
-			float value = (float) option.value;
+			FloatOption floatOption = (FloatOption) option;
+			float value = floatOption.value;
 			if (option == brightness) {
 				int percent = (int)(value * 200.0f);
 				if (percent == 0) {
diff --git a/src/main/java/net/minecraft/core/world/World.java b/src/main/java/net/minecraft/core/world/World.java
index 11ee88fd6..9e953dda8 100644
--- a/src/main/java/net/minecraft/core/world/World.java
+++ b/src/main/java/net/minecraft/core/world/World.java
@@ -1099,7 +1099,7 @@ public class World implements WorldSource {
 		int skyLight = getSavedLightValue(LightLayer.Sky, x, y, z);
 		int blockLight = Math.max(getSavedLightValue(LightLayer.Block, x, y, z), blockLightValue);
 		
-		if(getBlockLitInteriorSurface(x, y, z) || !isBlockOpaqueCube(x, y, z)) {
+		if(getBlockLitInteriorSurface(x, y, z)) {
 			skyLight = Math.max(skyLight, getSavedLightValue(LightLayer.Sky, x, y + 1, z));
 			skyLight = Math.max(skyLight, getSavedLightValue(LightLayer.Sky, x, y - 1, z));
 			skyLight = Math.max(skyLight, getSavedLightValue(LightLayer.Sky, x + 1, y, z));
diff --git a/src/main/java/net/minecraft/core/world/chunk/ChunkCache.java b/src/main/java/net/minecraft/core/world/chunk/ChunkCache.java
index 581f643fc..bd0db92c0 100644
--- a/src/main/java/net/minecraft/core/world/chunk/ChunkCache.java
+++ b/src/main/java/net/minecraft/core/world/chunk/ChunkCache.java
@@ -115,7 +115,7 @@ public class ChunkCache
 		int skyLight = worldObj.getSavedLightValue(LightLayer.Sky, x, y, z);
 		int blockLight = Math.max(worldObj.getSavedLightValue(LightLayer.Block, x, y, z), blockLightValue);
 		
-		if(getBlockLitInteriorSurface(x, y, z) || !isBlockOpaqueCube(x, y, z)) {
+		if(getBlockLitInteriorSurface(x, y, z)) {
 			skyLight = Math.max(skyLight, worldObj.getSavedLightValue(LightLayer.Sky, x, y + 1, z));
 			skyLight = Math.max(skyLight, worldObj.getSavedLightValue(LightLayer.Sky, x, y - 1, z));
 			skyLight = Math.max(skyLight, worldObj.getSavedLightValue(LightLayer.Sky, x + 1, y, z));
